@@ -20,7 +20,7 @@ read_gtfs <- function(gtfszip, quiet = FALSE){
       quiet = quiet,
       # files = c("agency", "routes", "stops", "stop_times", "shapes", "trips", "calendar", "calendar_dates", "frequencies"),
       fields = list(
-        routes = c("agency_id", "route_id", "route_type"),
+        routes = c("agency_id", "route_id", "route_type", "route_short_name", "route_long_name"),
         #stops = c("stop_id", "stop_lat", "stop_lon"),
         stop_times = c("trip_id", "arrival_time", "departure_time", "stop_id", "stop_sequence"),
         shapes = c("shape_id", "shape_pt_lat", "shape_pt_lon", "shape_pt_sequence"),
